#
# spec file for package pcr-oracle
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


Name:           pcr-oracle
VCS: https://src.suse.de/ALP-pool/pcr-oracle#f353b9fc19a20832faf4861dfaa69e829ff9cebb
Version:        0.4.6
Release:        3.1
Summary:        Predict TPM PCR values
License:        GPL-2.0-only
Group:          System/Boot
URL:            https://github.com/okirch/pcr-oracle
Source:         %{name}-%{version}.tar.xz
# PATCH-FEATURE-UPSTREAM systemd-boot.patch gh#okirch/pcr-oracle#31
Patch01:        systemd-boot.patch
# PATCH-FIX-UPATREAM fix-bsc1230316-predict-sbatlevelrt.patch gh#okirch/pcr-oracle#61
Patch02:        fix-bsc1230316-predict-sbatlevelrt.patch
# PATCH-FIX-UPATREAM fix-bsc1230316-predict-sbatlevelrt-sb-off.patch gh#okirch/pcr-oracle#61
Patch03:        fix-bsc1230316-predict-sbatlevelrt-sb-off.patch
# PATCH-FIX-UPATREAM fix-bsc1230316-make-pcr4-hard-requirement.patch gh#okirch/pcr-oracle#61
Patch04:        fix-bsc1230316-make-pcr4-hard-requirement.patch
BuildRequires:  libopenssl-devel >= 0.9.8
BuildRequires:  tpm2-0-tss-devel
Requires:       libtss2-tcti-device0
ExclusiveArch:  x86_64 aarch64 ppc64le riscv64

%description
This utility tries to predict the values of the TPM's Platform
Configuration Registers following an update of system components
like shim, grub, etc.

%prep
%autosetup -p1

%build
# beware, this is not autoconf
./configure --prefix /usr
make CCOPT="%optflags"

%install
make install DESTDIR=%{buildroot}
install -d %{buildroot}/%{_bindir}
mv %{buildroot}/bin/pcr-oracle %{buildroot}/%{_bindir}
rmdir %{buildroot}/bin

%files
%defattr(-,root,root)
%doc README.md
%doc test-authorized.sh
%{_bindir}/pcr-oracle
%{_mandir}/man8/pcr-oracle.8*

%changelog
* Mon Mar 10 2025 glin@suse.com
- Add fix-bsc1230316-predict-sbatlevelrt-sb-off.patch to fix the
  prediction of SbatLevelRT when Secure Boot is disabled
  (bsc#1230316)
- Add fix-bsc1230316-make-pcr4-hard-requirement.patch to make PCR4
  a hard requirement for SbatLevelRT prediction (bsc#1230316)
* Wed Feb 26 2025 glin@suse.com
- Add fix-bsc1230316-predict-sbatlevelrt.patch to predict
  SbatLevelRT for the next boot (bsc#1230316)
* Thu Oct 19 2023 aplanas@suse.com
- Add systemd-boot.patch to support systemd-cryptenroll JSON files
* Wed Jul 26 2023 glin@suse.com
- Add libtss2-tcti-device0 as the default TCTI interface to avoid
  the following error:
  Esys_Initialize() Initialize default tcti. ErrorCode (0x000a000a)
* Tue Jul  4 2023 okir@suse.com
- Added a _service file
- BuildRequire libopenssl-devel rather than openssl
- Updated to version 0.4.6:
  - recognize SOURCE_DATE_EPOCH for reproducible builds
  - Remove authorized policy file from the unseal action
  - Unseal the data without calling __pcr_policy_make()
  - Skip the variable event with 0 length (#26)
  - Add the new parameter: policy-name (#27)
  - Skip the leading operators when matching grub2 commands (#28)
  - microconf change: force rebuilding the sed script
* Mon Jun  5 2023 glin@suse.com
- Update to version 0.4.5
  - update manpage to reflect added support of unseal w/ tpm2.0 key
    format
  - Implement unseal for TPM 2.0 Key File
  - Update manpage to describe the new key-format switch
  - Add TPM 2.0 Key File support to 'seal-secret' and 'sign'
  - Add comment to SRK template regarding NODA flag.
  - pcr-oracle.8: add a section on pcr policy sealing
  - Add self-test subcommand to pcr-oracle
  - Rename __tss_check_error -> tss_check_error
  - Moved two tss related functions to a file of their own
  - Add test-pcr.sh script
  - Use the same SRK template as the one in grub2
  - Implement seal/unseal using a regular PCR policy
  - When displaying the DevicePath, print ACPI PNP ids
  - Handle failure to read EFI variables more gracefully
  - Gracefully handle AUTHORITY events for eg driver BSAs that
    reside in ROM
  - efi-variable rehash: break out the code to detect how the
    firmware hashed the event
* Thu Jun  1 2023 meissner@suse.com
- build with optflags, remove unneeded clean section, macro bindir
* Mon Jan 16 2023 okir@suse.com
- Updated to version 0.4.2
* Thu Jan  5 2023 msuchanek@suse.com
- Fix project URL
* Wed Jan  4 2023 okir@suse.com
- add --rsa-generate-key option
* Tue Jan  3 2023 okir@suse.com
- Updated to version 0.4.1:
  - disable debug messages from authenticode PECOFF parser
  - add --tpm-eventlog option
  - add manpage
* Mon Jan  2 2023 okir@suse.com
- Updated to version 0.4:
  - drop the dependency on tss2 fapi
  - introduce authorized policies
* Tue Nov  8 2022 okir@suse.com
- Establish pcr-oracle as standalone package, apart from fde-tools
